@@ -1,10 +1,10 @@
 /* Determine the virtual memory area of a given address.  Linux version.
-   Copyright (C) 2002, 2006, 2008, 2016-2017  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2002, 2006, 2008, 2016-2017, 2021  Bruno Haible <bruno@clisp.org>
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include "stackvma.h"
 #include <stdio.h>
@@ -22,10 +21,7 @@
 #include "stackvma-rofile.c"
 
 #if HAVE_MINCORE
-# define sigsegv_get_vma mincore_get_vma
-# define STATIC static
 # include "stackvma-mincore.c"
-# undef sigsegv_get_vma
 #endif
 
 struct callback_locals
